@@ -2,14 +2,18 @@
 
 use strict;
 use warnings;
-
+use oEdtk;
 use oEdtk::Main;
 use oEdtk::Config 		qw(config_read);
 use oEdtk::DBAdmin 		qw(db_connect csv_import);
+my $header='ED_SEQLOT,ED_LOTNAME,ED_DTPRINT,ED_DTPOST,ED_NBFACES,ED_NBPLIS,ED_DTPOST2';
 
 
-if (@ARGV < 1) {
-	die "Usage: $0 <acq_file>\n";
+if (@ARGV < 1 or $ARGV[0] =~/-h/i) {
+	warn "Usage: $0 <acq_file>\n";
+	warn "\n\tThis will import csv acq file into acq table.\n";
+	warn "\tcsv import file should have this structure :\n $header\n";
+	exit 1;
 }
 
 my $cfg = config_read('EDTK_DB');
@@ -18,7 +22,7 @@ my $dbh = db_connect($cfg, 'EDTK_DBI_DSN',
 
 csv_import($dbh, "EDTK_ACQ", $ARGV[0], 
 			{ 	mode => 'merge', 
-				header => 'ED_SEQLOT,ED_LOTNAME,ED_DTPRINT,ED_DTPOST,ED_NBFACES,ED_NBPLIS,ED_DTPOST2' 
+				header => $header 
 			});
 
 1;
\ No newline at end of file
